@@ -22,6 +22,13 @@ export function matchesStructure<T extends ESTree.Node>(
       // Handle `{ or: [a, b] }`
       return structure.or.some((node) => matchesStructure(obj, node));
     }
+    if ("anykey" in structure && Array.isArray(structure.anykey)) {
+      // Handle `{ anykey: [a, b] }`
+      const haystack = Array.isArray(obj) ? obj : Object.values(obj);
+      return structure.anykey.every((value) =>
+        haystack.some((el) => matchesStructure(el, value)),
+      );
+    }
     for (const [key, value] of Object.entries(structure)) {
       if (!matchesStructure(obj[key as keyof typeof obj], value)) {
         return false;
